@@ -61,17 +61,11 @@ class ChessDaskCluster:
         One task is created per square to find the control of both the sides. A worker client is
         used here because this method itself is run inside a worker
         """
-        task_futures = []
         tasks_for_game = ChessUtil.generate_ply_info_list_for_game(game)
         worker_client = get_client()
-        for game_task in tasks_for_game["ply_info_list"]:
-            task_futures.append(
-                worker_client.submit(ChessUtil.find_control_for_square, game_task))
+        task_futures = worker_client.map(ChessUtil.find_control_for_square, tasks_for_game["ply_info_list"])
         secede()
-        wait(task_futures)
-        control_list_for_game = []
-        for task_future in task_futures:
-            control_list_for_game.append(task_future.result())
+        control_list_for_game = worker_client.gather(task_futures)
         rejoin()
         game_data = ChessDaskCluster.get_game_data(control_list_for_game)
         game_data["filename"] = str(game_no) + " " + game.headers["Event"]
@@ -96,6 +90,8 @@ class ChessDaskCluster:
             config_values["worker_memory"] = 16
         if config_values["scheduler_memory"] is None:
             config_values["scheduler_memory"] = 16
+        if config_values["scheduler_cpu"] is None:
+            config_values["scheduler_cpu"] = 4
 
         if config_values["use_local_cluster"]:
             cluster = LocalCluster(n_workers=config_values["n_workers"],
@@ -108,6 +104,7 @@ class ChessDaskCluster:
                                     worker_cpu=config_values["worker_cpu"],
                                     worker_memory=str(config_values["worker_memory"]) +"GiB",
                                     scheduler_memory=str(config_values["scheduler_memory"]) +"GiB",
+                                    scheduler_cpu=config_values["scheduler_cpu"],
                                     software=config_values["software_environment_name"])
 
         self.client = Client(cluster)
